ClassMirror class

reflects a Dart language class.

Inheritance

Constructors

ClassMirror({required String name, bool isEnum = false, List? values, List<Annotation>? annotations, Map<String, FunctionMirror>? constructors, Map<String, DeclarationMirror>? fields, List<String>? getters, List<String>? setters, Map<String, FunctionMirror>? methods, Type superclass = Object, List<Type> superinterfaces = const [], bool isAbstract = false})
const

Properties

annotations → List<Annotation>?
annotations of the element
finalinherited
constructors → Map<String, FunctionMirror>?
Constructors of the class
final
fields → Map<String, DeclarationMirror>?
Fields of the class
final
getters → List<String>?
getters of the class
final
hashCode → int
The hash code for this object.
no setterinherited
isAbstract → bool
final
isEnum → bool
If the class is enum
final
methods → Map<String, FunctionMirror>?
methods of the class
final
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setters → List<String>?
setters of the class
final
superclass → Type
super-class of the class
final
superinterfaces → List<Type>
final
values → List?
If the class mirror is enum then this will return the values of the enum
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited