DeclarationMirror class

reflects attributes declared in a Dart program.

Inheritance

Constructors

DeclarationMirror({required String name, dynamic type, dynamic annotations, bool isFinal = false, bool isRequired = false, bool isNamed = false})
const

Properties

annotations → List<Annotation>?
annotations of the element
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isFinal → bool
Determines if the attribute is final
final
isNamed → bool
Determines if the attribute is named
final
isRequired → bool
Determines if the attribute is required
final
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → dynamic
Returns the type of the attribute, for example:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited