Mirror class abstract

Base class for mirrors

Implementers

Constructors

Mirror(String name, List<Annotation>? annotations)
const

Properties

annotations → List<Annotation>?
annotations of the element
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited